<?php

/**
 * @return SemantriaSessionCallbackHandler
 *  A Semantria Session Callback Handler for the active session.
 */
function _semantria_get_session_callback_handler() {
  $semantria_callback_handler = &drupal_static('semantria_session_callback_handler', NULL);
  if (!$semantria_callback_handler) {
    $semantria_callback_handler = new SemantriaSessionCallbackHandler();
  }
  return $semantria_callback_handler;
}

/**
 * Gets an initialized semantria session.
 */
function _semantria_get_session() {
  $semantria_session = &drupal_static('semantria_session', NULL);
  if (!$semantria_session) {
    $semantria_session = new \Semantria\Session(variable_get('semantria_api_key', NULL), variable_get('semantria_api_secret', NULL), NULL, NULL, TRUE);
    $callback_handler = _semantria_get_session_callback_handler();
    $semantria_session->setCallbackHandler($callback_handler);
  }
  return $semantria_session;
}

/**
 * Gets all available configurations from Semantria.
 */
function _semantria_get_available_configurations() {

  $configurations = &drupal_static('semantria_configurations', array());

  if (empty($configurations)) {
    $semantria_session = _semantria_get_session();
    foreach ($semantria_session->getConfigurations() as $configuration) {
      $configurations[$configuration['id']] = $configuration;
    }
    uasort($configurations, function($a, $b) {
      return strcmp($a['name'], $b['name']);
    });
  }
  return $configurations;

}
